@@ -29,7 +29,6 @@ Copyright_License {
 #include "Form/TabMenu.hpp"
 #include "Form/CheckBox.hpp"
 #include "Form/Button.hpp"
-#include "Form/DataField/FileReader.hpp"
 #include "Screen/Busy.hpp"
 #include "Screen/Key.h"
 #include "Screen/Layout.hpp"
@@ -38,12 +37,9 @@ Copyright_License {
 #include "Util/Macros.hpp"
 #include "Panels/ConfigPanel.hpp"
 #include "Panels/PagesConfigPanel.hpp"
-#include "Panels/PolarConfigPanel.hpp"
 #include "Panels/UnitsConfigPanel.hpp"
 #include "Panels/TimeConfigPanel.hpp"
 #include "Panels/LoggerConfigPanel.hpp"
-#include "Panels/LoggerInfoConfigPanel.hpp"
-#include "Panels/DevicesConfigPanel.hpp"
 #include "Panels/AirspaceConfigPanel.hpp"
 #include "Panels/SiteConfigPanel.hpp"
 #include "Panels/MapDisplayConfigPanel.hpp"
@@ -60,6 +56,7 @@ Copyright_License {
 #include "Panels/VarioConfigPanel.hpp"
 #include "Panels/TaskRulesConfigPanel.hpp"
 #include "Panels/TaskDefaultsConfigPanel.hpp"
+#include "Panels/ScoringConfigPanel.hpp"
 #include "Panels/InfoBoxesConfigPanel.hpp"
 #include "Interface.hpp"
 #include "Language/Language.hpp"
@@ -106,6 +103,7 @@ static constexpr TabMenuControl::PageItem pages[] = {
   {N_("Glide Computer"), 2, CreateGlideComputerConfigPanel },
   {N_("Wind"), 2, CreateWindConfigPanel },
   {N_("Route"), 2, CreateRouteConfigPanel },
+  {N_("Scoring"), 2, CreateScoringConfigPanel },
   {N_("FLARM, Other"), 3, CreateGaugesConfigPanel },
   {N_("Vario"), 3, CreateVarioConfigPanel },
 #ifdef HAVE_PCM_PLAYER
@@ -117,10 +115,7 @@ static constexpr TabMenuControl::PageItem pages[] = {
   {N_("Screen Layout"), 5, CreateLayoutConfigPanel },
   {N_("Pages"), 5, CreatePagesConfigPanel },
   {N_("InfoBox Sets"), 5, CreateInfoBoxesConfigPanel },
-  {N_("Devices"), 6, CreateDevicesConfigPanel },
-  {N_("Polar"), 6, CreatePolarConfigPanel },
   {N_("Logger"), 6, CreateLoggerConfigPanel },
-  {N_("Logger Info"), 6, CreateLoggerInfoConfigPanel },
   {N_("Units"), 6, CreateUnitsConfigPanel },
   // Important: all pages after Units in this list must not have data fields that are
   // unit-dependent because they will be saved after their units may have changed.
@@ -134,14 +129,6 @@ static constexpr TabMenuControl::PageItem pages[] = {
 #endif
 };
 
-WndForm &
-ConfigPanel::GetForm()
-{
-  assert(dialog != NULL);
-
-  return *dialog;
-}
-
 WndButton *
 ConfigPanel::GetExtraButton(unsigned number)
 {
@@ -167,7 +154,6 @@ OnUserLevel(CheckBoxControl &control)
   const bool expert = control.GetState();
   CommonInterface::SetUISettings().dialog.expert = expert;
   Profile::Set(ProfileKeys::UserLevel, expert);
-  dialog->FilterAdvanced(expert);
   tab_menu->UpdateLayout();
 }
 
@@ -198,6 +184,9 @@ OnCloseClicked()
 static bool
 FormKeyDown(unsigned key_code)
 {
+  if (tab_menu->InvokeKeyPress(key_code))
+    return true;
+
   switch (key_code) {
   case KEY_LEFT:
 #ifdef GNAV
@@ -267,7 +256,6 @@ PrepareConfigurationDialog()
   bool expert_mode = CommonInterface::GetUISettings().dialog.expert;
   CheckBox *cb = (CheckBox *)dialog->FindByName(_T("Expert"));
   cb->SetState(expert_mode);
-  dialog->FilterAdvanced(expert_mode);
 
   PrepareConfigurationMenu();
 
