@@ -158,7 +158,7 @@ public:
     style.Hide();
     style.TabStop();
 
-    const DialogLook &look = UIGlobals::GetDialogLook();
+    const ButtonLook &look = UIGlobals::GetDialogLook().button;
 
     const Layout layout = CalculateLayout(rc);
     edit_button = new WndButton(parent, look, _("Edit Point"),
@@ -251,8 +251,6 @@ public:
   void EditTaskPoint(unsigned ItemIndex);
   void OnMakeFinish();
 
-  bool OnKeyDown(unsigned key_code);
-
   /* virtual methods from Widget */
   virtual void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
 
@@ -263,6 +261,7 @@ public:
   virtual void ReClick() override;
   virtual void Show(const PixelRect &rc) override;
   virtual void Hide() override;
+  virtual bool KeyPress(unsigned key_code) override;
 
 protected:
   void RefreshView();
@@ -361,6 +360,7 @@ TaskEditPanel::OnPaintItem(Canvas &canvas, const PixelRect rc,
 {
   assert(DrawListIndex <= ordered_task->TaskSize());
 
+  const unsigned padding = Layout::GetTextPadding();
   const PixelScalar line_height = rc.bottom - rc.top;
 
   TCHAR buffer[120];
@@ -371,9 +371,8 @@ TaskEditPanel::OnPaintItem(Canvas &canvas, const PixelRect rc,
   // Draw "Add turnpoint" label
   if (DrawListIndex == ordered_task->TaskSize()) {
     canvas.Select(name_font);
-    canvas.SetTextColor(COLOR_BLACK);
     _stprintf(buffer, _T("  (%s)"), _("Add Turnpoint"));
-    canvas.DrawText(rc.left + line_height + Layout::FastScale(2),
+    canvas.DrawText(rc.left + line_height + padding,
                     rc.top + line_height / 2 - name_font.GetHeight() / 2,
                     buffer);
     return;
@@ -383,6 +382,47 @@ TaskEditPanel::OnPaintItem(Canvas &canvas, const PixelRect rc,
   GeoVector leg = tp.GetNominalLegVector();
   bool show_leg_info = leg.distance > fixed(0.01);
 
+  // Y-Coordinate of the second row
+  PixelScalar top2 = rc.top + name_font.GetHeight() + Layout::FastScale(4);
+
+  // Use small font for details
+  canvas.Select(small_font);
+
+  UPixelScalar leg_info_width = 0;
+  if (show_leg_info) {
+    // Draw leg distance
+    FormatUserDistanceSmart(leg.distance, buffer, true);
+    UPixelScalar width = leg_info_width = canvas.CalcTextWidth(buffer);
+    canvas.DrawText(rc.right - padding - width,
+                    rc.top + padding +
+                    (name_font.GetHeight() - small_font.GetHeight()) / 2,
+                    buffer);
+
+    // Draw leg bearing
+    FormatBearing(buffer, ARRAY_SIZE(buffer), leg.bearing);
+    width = canvas.CalcTextWidth(buffer);
+    canvas.DrawText(rc.right - padding - width, top2, buffer);
+
+    if (width > leg_info_width)
+      leg_info_width = width;
+
+    leg_info_width += padding;
+  }
+
+  // Draw details line
+  PixelScalar left = rc.left + line_height + padding;
+  OrderedTaskPointRadiusLabel(tp.GetObservationZone(), buffer);
+  if (!StringIsEmpty(buffer))
+    canvas.DrawClippedText(left, top2, rc.right - leg_info_width - left,
+                           buffer);
+
+  // Draw turnpoint name
+  canvas.Select(name_font);
+  OrderedTaskPointLabel(tp.GetType(), tp.GetWaypoint().name.c_str(),
+                        DrawListIndex, buffer);
+  canvas.DrawClippedText(left, rc.top + padding,
+                         rc.right - leg_info_width - left, buffer);
+
   // Draw icon
   const RasterPoint pt(rc.left + line_height / 2,
                        rc.top + line_height / 2);
@@ -395,48 +435,6 @@ TaskEditPanel::OnPaintItem(Canvas &canvas, const PixelRect rc,
                           pt, radius, task_look,
                           CommonInterface::GetMapSettings().airspace,
                           airspace_look);
-
-  // Y-Coordinate of the second row
-  PixelScalar top2 = rc.top + name_font.GetHeight() + Layout::FastScale(4);
-
-  // Use small font for details
-  canvas.Select(small_font);
-  canvas.SetTextColor(COLOR_BLACK);
-
-  UPixelScalar leg_info_width = 0;
-  if (show_leg_info) {
-    // Draw leg distance
-    FormatUserDistanceSmart(leg.distance, buffer, true);
-    UPixelScalar width = leg_info_width = canvas.CalcTextWidth(buffer);
-    canvas.DrawText(rc.right - Layout::FastScale(2) - width,
-                    rc.top + Layout::FastScale(2) +
-                    (name_font.GetHeight() - small_font.GetHeight()) / 2,
-                    buffer);
-
-    // Draw leg bearing
-    FormatBearing(buffer, ARRAY_SIZE(buffer), leg.bearing);
-    width = canvas.CalcTextWidth(buffer);
-    canvas.DrawText(rc.right - Layout::FastScale(2) - width, top2, buffer);
-
-    if (width > leg_info_width)
-      leg_info_width = width;
-
-    leg_info_width += Layout::FastScale(2);
-  }
-
-  // Draw details line
-  PixelScalar left = rc.left + line_height + Layout::FastScale(2);
-  OrderedTaskPointRadiusLabel(tp.GetObservationZone(), buffer);
-  if (!StringIsEmpty(buffer))
-    canvas.DrawClippedText(left, top2, rc.right - leg_info_width - left,
-                           buffer);
-
-  // Draw turnpoint name
-  canvas.Select(name_font);
-  OrderedTaskPointLabel(tp.GetType(), tp.GetWaypoint().name.c_str(),
-                        DrawListIndex, buffer);
-  canvas.DrawClippedText(left, rc.top + Layout::FastScale(2),
-                         rc.right - leg_info_width - left, buffer);
 }
 
 void
@@ -455,14 +453,14 @@ void
 TaskEditPanel::EditTaskPoint(unsigned ItemIndex)
 {
   if (ItemIndex < ordered_task->TaskSize()) {
-    if (dlgTaskPointShowModal(dialog.GetMainWindow(),
-                              &ordered_task, ItemIndex)) {
+    if (dlgTaskPointShowModal(&ordered_task, ItemIndex)) {
       *task_modified = true;
+      ordered_task->UpdateGeometry();
       RefreshView();
     }
   } else if (!ordered_task->IsFull()) {
 
-    OrderedTaskPoint* point = NULL;
+    OrderedTaskPoint* point = nullptr;
     AbstractTaskFactory &factory = ordered_task->GetFactory();
     const Waypoint* way_point =
       ShowWaypointListDialog(ordered_task->TaskSize() > 0
@@ -477,15 +475,16 @@ TaskEditPanel::EditTaskPoint(unsigned ItemIndex)
     } else {
       point = (OrderedTaskPoint*)factory.CreateIntermediate(*way_point);
      }
-    if (point == NULL)
+    if (point == nullptr)
       return;
 
-    if (factory.Append(*point, true))
+    if (factory.Append(*point, true)) {
       *task_modified = true;
+      ordered_task->UpdateGeometry();
+      RefreshView();
+    }
 
     delete point;
-
-    RefreshView();
   }
 }
 
@@ -504,7 +503,10 @@ TaskEditPanel::OnCursorMoved(unsigned index)
 void
 TaskEditPanel::OnMakeFinish()
 {
-  ordered_task->GetFactory().CheckAddFinish();
+  ordered_task->UpdateStatsGeometry();
+  if (ordered_task->GetFactory().CheckAddFinish())
+    ordered_task->UpdateGeometry();
+
   RefreshView();
 }
 
@@ -521,6 +523,7 @@ TaskEditPanel::MoveUp()
   GetList().SetCursorIndex(index - 1);
   *task_modified = true;
 
+  ordered_task->UpdateGeometry();
   RefreshView();
 }
 
@@ -537,11 +540,12 @@ TaskEditPanel::MoveDown()
   GetList().SetCursorIndex(index + 1);
   *task_modified = true;
 
+  ordered_task->UpdateGeometry();
   RefreshView();
 }
 
 bool
-TaskEditPanel::OnKeyDown(unsigned key_code)
+TaskEditPanel::KeyPress(unsigned key_code)
 {
   switch (key_code){
   case KEY_ESCAPE:
@@ -599,10 +603,6 @@ TaskEditPanel::Show(const PixelRect &rc)
 
   RefreshView();
 
-  dialog.SetKeyDownFunction([this](unsigned key_code){
-      return this->OnKeyDown(key_code);
-    });
-
   ListWidget::Show(rc);
 }
 
@@ -610,7 +610,6 @@ void
 TaskEditPanel::Hide()
 {
   dialog.ResetTaskView();
-  dialog.ClearKeyDownFunction();
 
   ListWidget::Hide();
 }
