@@ -26,14 +26,9 @@ Copyright_License {
 #include "Screen/Canvas.hpp"
 #include "FlarmTrafficWindow.hpp"
 #include "Blackboard/LiveBlackboard.hpp"
-#include "NMEA/MoreData.hpp"
 #include "Computer/Settings.hpp"
 #include "PageActions.hpp"
 
-#ifdef USE_GDI
-#include "Screen/Canvas.hpp"
-#endif
-
 #ifdef ENABLE_OPENGL
 #include "Screen/OpenGL/Scope.hpp"
 #endif
@@ -149,13 +144,11 @@ SmallTrafficWindow::OnPaint(Canvas &canvas)
 
   if (pressed) {
 #ifdef ENABLE_OPENGL
-    GLEnable blend(GL_BLEND);
-    glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+    const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     canvas.DrawFilledRectangle(0, 0, canvas.GetWidth(), canvas.GetHeight(),
                                COLOR_YELLOW.WithAlpha(80));
-#elif defined(USE_GDI)
-    const PixelRect rc = GetClientRect();
-    ::InvertRect(canvas, &rc);
+#else
+    canvas.InvertRectangle(GetClientRect());
 #endif
   }
 }
@@ -172,10 +165,7 @@ GaugeFLARM::Prepare(ContainerWindow &parent, const PixelRect &rc)
 void
 GaugeFLARM::Unprepare()
 {
-  SmallTrafficWindow *window =
-    (SmallTrafficWindow *)OverlappedWidget::GetWindow();
-  delete window;
-
+  DeleteWindow();
   OverlappedWidget::Unprepare();
 }
 
@@ -205,8 +195,6 @@ GaugeFLARM::OnGPSUpdate(const MoreData &basic)
 void
 GaugeFLARM::Update(const NMEAInfo &basic)
 {
-  SmallTrafficWindow *window =
-    (SmallTrafficWindow *)GetWindow();
-
-  window->Update(basic, blackboard.GetComputerSettings().team_code);
+  SmallTrafficWindow &window = (SmallTrafficWindow &)GetWindow();
+  window.Update(basic, blackboard.GetComputerSettings().team_code);
 }
