@@ -28,8 +28,6 @@ Copyright_License {
 #include "Computer/Settings.hpp"
 #include "Screen/Canvas.hpp"
 #include "Look/ThermalBandLook.hpp"
-#include <algorithm>
-#include "Engine/Task/TaskBehaviour.hpp"
 #include "Units/Units.hpp"
 #include "Screen/Layout.hpp"
 
@@ -37,6 +35,8 @@ Copyright_License {
 #include "Screen/OpenGL/Scope.hpp"
 #endif
 
+#include <algorithm>
+
 void
 ThermalBandRenderer::ScaleChart(const DerivedInfo &calculated,
                                  const ComputerSettings &settings_computer,
@@ -58,7 +58,7 @@ ThermalBandRenderer::_DrawThermalBand(const MoreData &basic,
                                       ChartRenderer &chart,
                                       const TaskBehaviour& task_props,
                                       const bool is_infobox,
-                                      const OrderedTaskBehaviour *ordered_props) const
+                                      const OrderedTaskSettings *ordered_props) const
 {
   const ThermalBandInfo &thermal_band = calculated.thermal_band;
 
@@ -138,7 +138,7 @@ ThermalBandRenderer::_DrawThermalBand(const MoreData &basic,
 
     if (!is_infobox) {
 #ifdef ENABLE_OPENGL
-      const GLEnable blend(GL_BLEND);
+      const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 #endif
       chart.DrawFilledY(thermal_profile, look.brush, fpen);
     } else
@@ -169,7 +169,7 @@ ThermalBandRenderer::DrawThermalBand(const MoreData &basic,
                                      const PixelRect &rc,
                                      const TaskBehaviour& task_props,
                                      const bool is_map,
-                                     const OrderedTaskBehaviour *ordered_props) const
+                                     const OrderedTaskSettings *ordered_props) const
 {
   ChartRenderer chart(chart_look, canvas, rc);
   if (is_map) {
