@@ -133,8 +133,8 @@ struct RenderedText {
 #ifdef USE_FREETYPE
   RenderedText(unsigned width, unsigned height, const uint8_t *buffer) {
     glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
-    texture = new GLTexture(GL_LUMINANCE, width, height,
-                            GL_LUMINANCE, GL_UNSIGNED_BYTE,
+    texture = new GLTexture(GL_ALPHA, width, height,
+                            GL_ALPHA, GL_UNSIGNED_BYTE,
                             buffer);
   }
 #elif defined(ANDROID)
